@@ -135,7 +135,7 @@ sub _delegate_to_cb_or_private {
             for ( $method ) {
 
                 /login_resource_owner|confirm_by_resource_owner|verify_client/ && do {
-                    return $cb->( $obj, @args{ qw/ client_id scopes redirect_uri / } );
+                    return $cb->( $obj, @args{ qw/ client_id scopes redirect_uri response_type / } );
                 };
 
 				$self->_uses_user_passwords && /verify_user_password/ && do {
